@@ -2,8 +2,8 @@ class Get(object):
 
     def __init__(self):
         self._status = None
-        self._inboundsms = None
-        self._smsreceived = None
+        self._sms_received = None
+        self._sms_reply = None
         self._result = None
 
     def Status(self,**kwargs):
@@ -14,21 +14,21 @@ class Get(object):
 
         return self._status
     
-    def InboundSMS(self,**kwargs):
+    def SMSReceived(self,**kwargs):
 
-        if self._inboundsms == None:
-            from tnzapi.get.inbound_sms import InboundSMS
-            self._inboundsms = InboundSMS(kwargs)
-
-        return self._inboundsms
-
-    def SMSReceived(self, **kwargs):
-
-        if self._smsreceived == None:
+        if self._sms_received == None:
             from tnzapi.get.sms_received import SMSReceived
-            self._smsreceived = SMSReceived(kwargs)
+            self._sms_received = SMSReceived(kwargs)
 
-        return self._smsreceived
+        return self._sms_received
+
+    def SMSReply(self, **kwargs):
+
+        if self._sms_reply == None:
+            from tnzapi.get.sms_reply import SMSReply
+            self._sms_reply = SMSReply(kwargs)
+
+        return self._sms_reply
     
     def Result(self, **kwargs):
 
